<template>
    <header class="pc-header">
        <div class="header-wrapper">
            <!-- Mobile Menu -->
            <div class="me-auto pc-mob-drp">
                <ul class="list-unstyled">
                    <li class="pc-h-item header-mobile-collapse">
                        <a href="#" class="pc-head-link head-link-secondary ms-0" id="sidebar-hide">
                            <i class="ti ti-menu-2"></i>
                        </a>
                    </li>
                    <li class="pc-h-item pc-sidebar-popup">
                        <a href="#" class="pc-head-link head-link-secondary ms-0" id="mobile-collapse">
                            <i class="ti ti-menu-2"></i>
                        </a>
                    </li>
                </ul>
            </div>

            <!-- Welcome Text -->
            <div class="ms-auto d-flex align-items-center pe-3">
                <span class="fw-semibold text-muted">Selamat Datang, Admin</span>
            </div>
        </div>
    </header>
</template>

<script setup>
import { onMounted, onUnmounted, watch } from "vue";
import { usePage } from "@inertiajs/vue3";

const page = usePage();

let sidebarClickHandler = null;
let mobileClickHandler = null;
let overlayClickHandler = null;
let dropdownClickHandlers = [];
let documentClickHandler = null;

const setupSidebarListeners = () => {
    const sidebarToggle = document.getElementById('sidebar-hide');
    const mobileCollapse = document.getElementById('mobile-collapse');
    const sidebar = document.querySelector('.pc-sidebar');
    const overlay = document.createElement('div');
    overlay.classList.add('pc-menu-overlay');

    cleanupListeners();

    if (sidebarToggle && sidebar) {
        sidebarClickHandler = () => {
            sidebar.classList.toggle('pc-sidebar-hide');
        };
        sidebarToggle.addEventListener('click', sidebarClickHandler);
    }

    if (mobileCollapse && sidebar) {
        mobileClickHandler = () => {
            if (sidebar.classList.contains('mob-sidebar-active')) {
                sidebar.classList.remove('mob-sidebar-active');
                overlay.remove();
            } else {
                sidebar.classList.add('mob-sidebar-active');
                sidebar.appendChild(overlay);
            }
        };
        mobileCollapse.addEventListener('click', mobileClickHandler);

        overlayClickHandler = () => {
            sidebar.classList.remove('mob-sidebar-active');
            overlay.remove();
        };
        overlay.addEventListener('click', overlayClickHandler);
    }

    documentClickHandler = (e) => {
        if (!e.target.closest('.dropdown')) {
            const dropdowns = document.querySelectorAll('.dropdown-menu.show');
            dropdowns.forEach(menu => menu.classList.remove('show'));
        }
    };
    document.addEventListener('click', documentClickHandler);
};

const cleanupListeners = () => {
    const sidebarToggle = document.getElementById('sidebar-hide');
    const mobileCollapse = document.getElementById('mobile-collapse');

    if (sidebarToggle && sidebarClickHandler) {
        sidebarToggle.removeEventListener('click', sidebarClickHandler);
    }

    if (mobileCollapse && mobileClickHandler) {
        mobileCollapse.removeEventListener('click', mobileClickHandler);
    }

    if (overlayClickHandler) {
        document.querySelector('.pc-menu-overlay')?.removeEventListener('click', overlayClickHandler);
    }

    dropdownClickHandlers.forEach(({ toggle, handler }) => {
        toggle.removeEventListener('click', handler);
    });
    dropdownClickHandlers = [];

    if (documentClickHandler) {
        document.removeEventListener('click', documentClickHandler);
    }
};

onMounted(() => {
    setupSidebarListeners();
});

watch(() => page.url, () => {
    setupSidebarListeners();
});

onUnmounted(() => {
    cleanupListeners();
});
</script>
